@@ -1,7 +1,7 @@
 from PyQt5.QtCore import pyqtSignal
 
 from gridplayer.player.managers.base import ManagerBase
-from gridplayer.utils.misc import qt_connect
+from gridplayer.utils.qt import qt_connect
 from gridplayer.utils.single_instance import Listener
 
 
@@ -16,5 +16,7 @@ class InstanceListenerManager(ManagerBase):
 
         qt_connect(
             (self._instance_listener.open_files, self.files_opened),
-            (self.destroyed, self._instance_listener.cleanup),
         )
+
+    def cleanup(self):
+        self._instance_listener.cleanup()
